@@ -48,7 +48,7 @@ struct toptenentry {
 	int deathdnum, deathlev;
 	int maxlvl, hp, maxhp, deaths;
 	int ver_major, ver_minor, patchlevel;
-	char deathdate[8], birthdate[8]; /* see readentry about size */
+	long deathdate, birthdate;
 	int uid;
 	char plchar;
 	char sex;
@@ -126,35 +126,11 @@ FILE *rfile;
 struct toptenentry *tt;
 {
 #ifdef NO_SCAN_BRACK
-	static char *fmt = "%d %d %d %ld %d %d %d %d %d %d %6s %6s %d%*c%c%c %s %s%*c";
+	static char *fmt = "%d %d %d %ld %d %d %d %d %d %d %ld %ld %d%*c%c%c %s %s%*c";
 #else
-	static char *fmt = "%d.%d.%d %ld %d %d %d %d %d %d %6s %6s %d %c%c %[^,],%[^\n]%*c";
+	static char *fmt = "%d.%d.%d %ld %d %d %d %d %d %d %ld %ld %d %c%c %[^,],%[^\n]%*c";
 #endif
 
-#ifdef __BEOS__
-	/*
-	Test for a bug in Be's *scanf functions.  This exists in at least
-	versions DR8.2 and earlier.  We should eventually be able to
-	remove this special code..
-
-	The bug is that a read of a sized string field, e.g. %6s, leaves
-	the last character of the string to be read again.  The work-round
-	is to increase the read size by 1.  This means that deathdate and
-	birthdate need a size of 8 (7 chars + 1 NULL) instead of a size
-	7 (6 chars + 1 NULL).
-	*/
-	static boolean tested_scanf_bug = FALSE;
-
-	if (!tested_scanf_bug) {
-		char s1[16], s2[16];
-		
-		tested_scanf_bug  = TRUE;
-		(void) sscanf("123456 789012", "%6s %6s", s1, s2);
-		if (strcmp(s2, "789012") != 0)
-			fmt = "%d.%d.%d %ld %d %d %d %d %d %d %7s %7s %d %c%c %[^,],%[^\n]%*c";
-	}
-#endif /* __BEOS__ */ 
-
 #ifdef UPDATE_RECORD_IN_PLACE
 	/* note: fscanf() below must read the record's terminating newline */
 	final_fpos = tt->fpos = ftell(rfile);
@@ -164,7 +140,7 @@ struct toptenentry *tt;
 			&tt->ver_major, &tt->ver_minor, &tt->patchlevel,
 			&tt->points, &tt->deathdnum, &tt->deathlev,
 			&tt->maxlvl, &tt->hp, &tt->maxhp, &tt->deaths,
-			tt->deathdate, tt->birthdate,
+			&tt->deathdate, &tt->birthdate,
 			&tt->uid, &tt->plchar, &tt->sex,
 			tt->name, tt->death) != TTFIELDS)
 #undef TTFIELDS
@@ -177,6 +153,12 @@ struct toptenentry *tt;
 		}
 #endif
 	}
+
+	/* check old score entries for Y2K problem and fix whenever found */
+	if (tt->points > 0) {
+		if (tt->birthdate < 19000000L) tt->birthdate += 19000000L;
+		if (tt->deathdate < 19000000L) tt->deathdate += 19000000L;
+	}
 }
 
 static void
@@ -187,9 +169,9 @@ struct toptenentry *tt;
 #ifdef NO_SCAN_BRACK
 	nsb_mung_line(tt->name);
 	nsb_mung_line(tt->death);
-	(void) fprintf(rfile,"%d %d %d %ld %d %d %d %d %d %d %6s %6s %d %c%c %s %s\n",
+	(void) fprintf(rfile,"%d %d %d %ld %d %d %d %d %d %d %ld %ld %d %c%c %s %s\n",
 #else
-	(void) fprintf(rfile,"%d.%d.%d %ld %d %d %d %d %d %d %6s %6s %d %c%c %s,%s\n",
+	(void) fprintf(rfile,"%d.%d.%d %ld %d %d %d %d %d %d %ld %ld %d %c%c %s,%s\n",
 #endif
 		tt->ver_major, tt->ver_minor, tt->patchlevel,
 		tt->points, tt->deathdnum, tt->deathlev,
@@ -295,8 +277,8 @@ int how;
 			(void) strncat(t0->death, killer, DTHSZ);
 			break;
 	}
-	Strcpy(t0->birthdate, yymmdd(u.ubirthday));
-	Strcpy(t0->deathdate, yymmdd(0L));
+	t0->birthdate = yyyymmdd(u.ubirthday);
+	t0->deathdate = yyyymmdd((time_t)0L);
 	t0->tt_next = 0;
 #ifdef UPDATE_RECORD_IN_PLACE
 	t0->fpos = -1L;
@@ -476,7 +458,7 @@ int how;
 	    t1->uid = t1->deathdnum = t1->deathlev = 0;
 	    t1->maxlvl = t1->hp = t1->maxhp = t1->deaths = 0;
 	    t1->plchar = t1->sex = '-';
-	    Strcpy(t1->birthdate, strcpy(t1->deathdate, yymmdd(0L)));
+	    t1->birthdate = t1->deathdate = yyyymmdd((time_t)0L);
 	    Strcpy(t1->name, "@");
 	    Strcpy(t1->death, "<eod>\n");
 	    writeentry(rfile, t1);
